#
# make.matlab - Make MATLAB functions for reading headers and time-series data
#               from blocked-binary format files for Linux (i386).
#
# Shell command syntax: make -f make.matlab [ all | bbdata | bbihdr | bbrhdr |
#                                             bbthdr | clean ]
#
#
# Author:      Lawrence M. Baker
#              U.S. Geological Survey
#              345 Middlefield Road  MS977
#              Menlo Park, CA  94025
#              baker@usgs.gov
#
#                                 Disclaimer
#
# Although  this  program  has  been  used  by  the  U.S. Geological Survey, no
# warranty, expressed or implied, is made by the USGS as to  the  accuracy  and
# functioning  of  the program and related program material, nor shall the fact
# of distribution constitute  any  such  warranty,  and  no  responsibility  is
# assumed by the USGS in connection therewith.
#
#
# Modification History:
#
# 30-Nov-2004  L. M. Baker      Original version.
#

MEX = /usr/local/matlab6p5/bin/mex

MEXFLAGS = -U_GNU_SOURCE -D_POSIX_SOURCE

LIBS = libvfbb.a

all:		bbdata bbihdr bbrhdr bbthdr

#
#   bbdata('file'[,first_pt,last_pt]); reads time-series data
#
bbdata:
	$(MEX) ../src/bbdata.c $(MEXFLAGS) $(LIBS)

#
#   bbihdr('file'[,ihdr_no]); reads an integer header
#
bbihdr:
	$(MEX) ../src/bbihdr.c $(MEXFLAGS) $(LIBS)

#
#   bbrhdr('file'[,rhdr_no]); reads a real header
#
bbrhdr:
	$(MEX) ../src/bbrhdr.c $(MEXFLAGS) $(LIBS)

#
#   bbthdr('file'[,thdr_no]); reads an ASCII text header
#
bbthdr:
	$(MEX) ../src/bbthdr.c $(MEXFLAGS) $(LIBS)

clean:
	$(RM) -f bbdata.mexglx bbihdr.mexglx bbrhdr.mexglx bbthdr.mexglx \
	         bbdata.o      bbihdr.o      bbrhdr.o      bbthdr.o
