#
# make.matlab - Make MATLAB functions for reading headers and time-series data
#               from blocked-binary format files for Macintosh OS X (G5).
#
# Shell command syntax: make -f make.matlab [ all | bbdata | bbihdr | bbrhdr |
#                                             bbthdr | clean ]
#
#
# Author:      Lawrence M. Baker
#              U.S. Geological Survey
#              345 Middlefield Road  MS977
#              Menlo Park, CA  94025
#              baker@usgs.gov
#
#                                 Disclaimer
#
# Although  this  program  has  been  used  by  the  U.S. Geological Survey, no
# warranty, expressed or implied, is made by the USGS as to  the  accuracy  and
# functioning  of  the program and related program material, nor shall the fact
# of distribution constitute  any  such  warranty,  and  no  responsibility  is
# assumed by the USGS in connection therewith.
#
#
# Modification History:
#
# 04-Oct-2004  L. M. Baker      Original version.
#

# Note: The mexopts.sh in this directory has been modified to include the ld
# option "-read_only_relocs suppress".  It also has MatLab's modification to
# change the preprocessor option from "-traditional-cpp" to "-no-cpp-precomp".
# To use this file, copy it to ~/.matlab/R13.

MEX = /Applications/MATLAB6p5p1/bin/mex

MEXFLAGS = -D_POSIX_SOURCE

LIBS = libvfbb.a

all:		bbdata bbihdr bbrhdr bbthdr

#
#   bbdata('file'[,first_pt,last_pt]); reads time-series data
#
bbdata:
	$(MEX) ../src/bbdata.c $(MEXFLAGS) $(LIBS)

#
#   bbihdr('file'[,ihdr_no]); reads an integer header
#
bbihdr:
	$(MEX) ../src/bbihdr.c $(MEXFLAGS) $(LIBS)

#
#   bbrhdr('file'[,rhdr_no]); reads a real header
#
bbrhdr:
	$(MEX) ../src/bbrhdr.c $(MEXFLAGS) $(LIBS)

#
#   bbthdr('file'[,thdr_no]); reads an ASCII text header
#
bbthdr:
	$(MEX) ../src/bbthdr.c $(MEXFLAGS) $(LIBS)

clean:
	$(RM) -f bbdata.mexaxp bbihdr.mexaxp bbrhdr.mexaxp bbthdr.mexaxp \
	         bbdata.o      bbihdr.o      bbrhdr.o      bbthdr.o
