#
# make.matlab - Make MATLAB functions for reading headers and time-series data
#               from blocked-binary format files for Solaris (Sparc and i386).
#
# Shell command syntax: make -f make.matlab [ all | bbdata | bbihdr | bbrhdr |
#                                             bbthdr | clean ]
#
#
# Author:      Lawrence M. Baker
#              U.S. Geological Survey
#              345 Middlefield Road  MS977
#              Menlo Park, CA  94025
#              baker@usgs.gov
#
#                                 Disclaimer
#
# Although  this  program  has  been  used  by  the  U.S. Geological Survey, no
# warranty, expressed or implied, is made by the USGS as to  the  accuracy  and
# functioning  of  the program and related program material, nor shall the fact
# of distribution constitute  any  such  warranty,  and  no  responsibility  is
# assumed by the USGS in connection therewith.
#
#
# Modification History:
#
#  1-Feb-2001  L. M. Baker      Original version.
# 15-Feb-2001  L. M. Baker      Use conversion routines in libvfbb.a.
#

# sparc if Sun SPARC architecture; i386 if Intel 80x86 architecture
ARCH:sh = uname -p

MEX = /opt/matlab/bin/mex

LIBS = libvfbb.a

all:		bbdata bbihdr bbrhdr bbthdr

#
#   bbdata('file'[,first_pt,last_pt]); reads time-series data
#
bbdata:
	cd $(ARCH); $(MEX) ../../src/bbdata.c $(LIBS)

#
#   bbihdr('file'[,ihdr_no]); reads an integer header
#
bbihdr:
	cd $(ARCH); $(MEX) ../../src/bbihdr.c $(LIBS)

#
#   bbrhdr('file'[,rhdr_no]); reads a real header
#
bbrhdr:
	cd $(ARCH); $(MEX) ../../src/bbrhdr.c $(LIBS)

#
#   bbthdr('file'[,thdr_no]); reads an ASCII text header
#
bbthdr:
	cd $(ARCH); $(MEX) ../../src/bbthdr.c $(LIBS)

clean:
	cd $(ARCH); $(RM) bbdata.mex bbihdr.mex bbrhdr.mex bbthdr.mex \
	                  bbdata.o   bbihdr.o   bbrhdr.o   bbthdr.o
