/******************************************************************************
 *                                                                            *
 * CLISubs.c - OpenVMS DCL command line parser for the DHead program.         *
 *                                                                            *
 * OpenVMS command line format:                                               *
 *                                                                            *
 *    $ DHEAD /HELP    or                                                     *
 *    $ DHEAD /VERSION or                                                     *
 *    $ DHEAD DR100_file [ /OUTPUT=listing_file[.lis] ]                       *
 *                                                                            *
 * Funtion prototype:                                                         *
 *                                                                            *
 *    int parse_command_line( int argc, char *argv[] );                       *
 *                                                                            *
 * where  the  int  returned  by parse_command_line() is an OpenVMS condition *
 * code value (SS$_NORMAL is success).                                        *
 *                                                                            *
 ******************************************************************************/


/* Disable (erroneous?) compiler warning from VAX DEC C compiler */

#ifdef __vax
#pragma message disable ( addrconstext )
#endif


/* ANSI-Standard Headers */

#include <stdlib.h>		/* NULL, malloc() */
#include <string.h>		/* strcpy() */

/* OpenVMS-Specific Headers */

#include <climsgdef.h>		/* CLI$_INSFPRM, CLI$_PRESENT */
#include <cli$routines.h>	/* cli$get_value(), cli$present() */
#include <descrip.h>		/* $DESCRIPTOR */
#ifdef __vax
#include <ints.h>		/* uint16 */
#define uint16_t uint16
#else
#include <inttypes.h>		/* uint16_t */
#endif
#include <ssdef.h>		/* SS$_INSFMEM, SS$_NORMAL */
#include <stsdef.h>		/* STS$M_SUCCESS */

#define IS_CV_OK( cv ) ( cv & STS$M_SUCCESS )
#ifndef TRUE
#define TRUE ( 0 == 0 )
#endif
#ifndef FALSE
#define FALSE ( 0 != 0 )
#endif

/* Global Data */

extern int boolCLIHelp;
extern int boolCLIVersion;
extern char *strCLIDR100File;
extern int boolCLIOutput;
extern char *strCLIOutput;


/****************************************************** parse_command_line () */

/* Local Static Data */

static const $DESCRIPTOR( dscDR100FILE, "DR100FILE" );	/* P1       */
static const $DESCRIPTOR( dscHELP,      "HELP"      );	/* /HELP    */
static const $DESCRIPTOR( dscOUTPUT,    "OUTPUT"    );	/* /OUTPUT  */
static const $DESCRIPTOR( dscVERSION,   "VERSION"   );	/* /VERSION */


int parse_command_line( int argc, char *argv[] ) {

   int      cvStatus;
   uint16_t intStrValueLen;
   char     strValue[256];
   const $DESCRIPTOR( dscValue, strValue );	/* Buffer for return value */
   $DESCRIPTOR( dscResult, strValue );		/* Returned value */


   boolCLIHelp    = cli$present( &dscHELP		/* void *entity_desc          */
                               ) == CLI$_PRESENT;

   boolCLIVersion = cli$present( &dscVERSION		/* void *entity_desc          */
                               ) == CLI$_PRESENT;

   strCLIDR100File = NULL;
   boolCLIOutput   = FALSE;
   strCLIOutput    = NULL;

   if ( boolCLIHelp || boolCLIVersion )
      return SS$_NORMAL;

   if ( cli$present( &dscDR100FILE		/* void *entity_desc          */
                   ) != CLI$_PRESENT )
      return CLI$_INSFPRM;

   cvStatus =
      cli$get_value( &dscDR100FILE,		/* void *entity_desc          */
                     &dscValue,			/* void *retdesc              */
                     &intStrValueLen		/* unsigned short int *retlength */
                   );
   if ( !IS_CV_OK( cvStatus ) )
      return cvStatus;
   strValue[intStrValueLen] = '\0';

   strCLIDR100File = (char *) malloc( intStrValueLen + 1 );
   if ( strCLIDR100File == NULL )
      return SS$_INSFMEM;
   strcpy( strCLIDR100File, strValue );

   boolCLIOutput  = cli$present( &dscOUTPUT	/* void *entity_desc          */
                               ) == CLI$_PRESENT;
   if ( boolCLIOutput ) {

      cvStatus =
         cli$get_value( &dscOUTPUT,		/* void *entity_desc          */
                        &dscValue,		/* void *retdesc              */
                        &intStrValueLen		/* unsigned short int *retlength */
                      );
      if ( !IS_CV_OK( cvStatus ) )
         return cvStatus;
      strValue[intStrValueLen] = '\0';

      strCLIOutput = (char *) malloc( intStrValueLen + 1 );
      if ( strCLIOutput == NULL )
         return SS$_INSFMEM;
      strcpy( strCLIOutput, strValue );

   }

   return SS$_NORMAL;

}
