$ verify = 'F$Verify( 0 )'
$!
$! Make.matlab - Create MATLAB functions for reading headers and time-series
$!               data from blocked-binary format files for OpenVMS (VAX and
$!               Alpha).
$!
$! DCL command syntax: @Make.matlab [ all | bbdata | bbihdr | bbrhdr | bbthdr |
$!                                    clean ]
$!
$!
$! Author:      Lawrence M. Baker
$!              U.S. Geological Survey
$!              345 Middlefield Road  MS977
$!              Menlo Park, CA  94025
$!              baker@usgs.gov
$!
$!                                 Disclaimer
$!
$! Although  this  program  has  been  used  by  the  U.S. Geological Survey, no
$! warranty, expressed or implied, is made by the USGS as to  the  accuracy  and
$! functioning  of  the program and related program material, nor shall the fact
$! of distribution constitute  any  such  warranty,  and  no  responsibility  is
$! assumed by the USGS in connection therewith.
$!
$!
$! Modification History:
$!
$! 24-Mar-1994  L. M. Baker      Automatically invoke @MatLab_SyLogin if
$!                                  FMexN DCL commands are undefined.
$!                               Convert explicit @FMexN to FMexN DCL command.
$! 21-Jul-1995  L. M. Baker      Make D_Float version on OpenVMS/VAX only.
$! 16-Jul-1998  L. M. Baker      Use V5 MEX command if defined.
$! 24-May-2000  L. M. Baker      Replace Fortran with C.
$!                               V5 uses IEEE floating-point exclusively, so we
$!                                  must manually convert VAX F floating-point
$!                                  format data to IEEE S floating-point format.
$! 22-Jul-2001  L. M. Baker      Use conversion routines in LibVFBB.olb (re-
$!                                  quires upcased definitions because MatLab
$!                                  uses DEC C /Names=As_Is option).
$!
$!
$ args = "||all|bbdata|bbihdr|bbrhdr|bbthdr|clean|"
$ P1 = F$Edit( P1, "TRIM,LOWERCASE" )
$ If ( F$Locate( "|''P1'|", args ) .eq. F$Length( args ) )
$ Then
$    Write Sys$Error -
        "DCL command syntax: @Make.matlab [ all | bbdata | bbihdr | ", -
        "bbrhdr | bbthdr | clean ]"
$    Goto EXIT
$ EndIf
$!
$ arch = F$GetSYI( "ARCH_NAME" )
$ Set Verify
$ Set Default [.'arch']
$ junk = 'F$Verify( 0 )'
$ If ( P1 .eqs. "clean" ) Then $ Goto 'P1'
$!
$ If ( F$Type( MEX ) .nes. "" )
$ Then
$!
$!   MatLab V5 (Alpha only)
$!
$    If ( P1 .nes. "" ) Then $ Goto 'P1'_V5
$!
$ALL_V5:
$!
$!   bbdata('file'[,first_pt,last_pt]); reads time-series data
$!
$BBDATA_V5:
$!
$    Write Sys$Output "$ MEX [--.Src]BBData.c LibVFBB.olb"
$    MEX [--.Src]BBData.c LibVFBB.olb
$    Write Sys$Output "$ Purge BBData.mex*"
$    Purge BBData.mex*
$!
$    If ( P1 .eqs. "bbdata" ) Then $ Goto DONE
$!
$!   bbihdr('file'[,ihdr_no]); reads an integer header
$!
$BBIHDR_V5:
$!
$    Write Sys$Output "$ MEX [--.Src]BBIHdr.c LibVFBB.olb"
$    MEX [--.Src]BBIHdr.c LibVFBB.olb
$    Write Sys$Output "$ Purge BBIHdr.mex*"
$    Purge BBIHdr.mex*
$!
$    If ( P1 .eqs. "bbihdr" ) Then $ Goto DONE
$!
$!   bbrhdr('file'[,rhdr_no]); reads a real header
$!
$BBRHDR_V5:
$!
$    Write Sys$Output "$ MEX [--.Src]BBRHdr.c LibVFBB.olb"
$    MEX [--.Src]BBRHdr.c LibVFBB.olb
$    Write Sys$Output "$ Purge BBRHdr.mex*"
$    Purge BBRHdr.mex*
$!
$    If ( P1 .eqs. "bbrhdr" ) Then $ Goto DONE
$!
$!   bbthdr('file'[,thdr_no]); reads an ASCII text header
$!
$BBTHDR_V5:
$!
$    Write Sys$Output "$ MEX [--.Src]BBTHdr.c LibVFBB.olb"
$    MEX [--.Src]BBTHdr.c LibVFBB.olb
$    Write Sys$Output "$ Purge BBTHdr.mex*"
$    Purge BBTHdr.mex*
$!
$    If ( P1 .eqs. "bbthdr" ) Then $ Goto DONE
$!
$ Else
$!
$!   MatLab V4 (VAX and Alpha)
$!
$    If ( F$Type( FMEXG ) .eqs. "" )
$    Then
$       Write Sys$Output "$ @MatLab:[Etc]MatLab_SyLogin"
$       @MatLab:[Etc]MatLab_SyLogin
$    EndIf
$!
$    If ( P1 .nes. "" ) Then $ Goto 'P1'_V4
$!
$ALL_V4:
$!
$!   bbdata('file'[,first_pt,last_pt]); reads time-series data
$!
$BBDATA_V4:
$!
$    If ( arch .eqs. "VAX" )
$    Then
$       Write Sys$Output "$ CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) ", -
                         "/Include=MatLab:[Extern.Include] [--.Src]BBData"
$       CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) -
           /Include=MatLab:[Extern.Include] [--.Src]BBData
$       Write Sys$Output "$ CMexD BBData,LibVFBB/Library"
$       CMexD BBData,LibVFBB/Library
$       Write Sys$Output "$ Delete BBData.obj;*"
$       Delete BBData.obj;*
$       Write Sys$Output "$ Purge BBData.mex*"
$       Purge BBData.mex*
$    EndIf
$    Write Sys$Output "$ CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) ", -
                      "/Float=G_Float /Include=MatLab:[Extern.Include] ", -
                      "[--.Src]BBData"
$    CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) /Float=G_Float -
        /Include=MatLab:[Extern.Include] [--.Src]BBData
$    Write Sys$Output "$ CMexG BBData,LibVFBB/Library"
$    CMexG BBData,LibVFBB/Library
$    Write Sys$Output "$ Delete BBData.obj;*"
$    Delete BBData.obj;*
$    Write Sys$Output "$ Purge BBData.mex*"
$    Purge BBData.mex*
$!
$    If ( P1 .eqs. "bbdata" ) Then $ Goto DONE
$!
$!   bbihdr('file'[,ihdr_no]); reads an integer header
$!
$BBIHDR_V4:
$!
$    If ( arch .eqs. "VAX" )
$    Then
$       Write Sys$Output "$ CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) ", -
                         "/Include=MatLab:[Extern.Include] [--.Src]BBIHdr"
$       CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) -
           /Include=MatLab:[Extern.Include] [--.Src]BBIHdr
$       Write Sys$Output "$ CMexD BBIHdr,LibVFBB/Library"
$       CMexD BBIHdr,LibVFBB/Library
$       Write Sys$Output "$ Delete BBIHdr.obj;*"
$       Delete BBIHdr.obj;*
$       Write Sys$Output "$ Purge BBIHdr.mex*"
$       Purge BBIHdr.mex*
$    EndIf
$    Write Sys$Output "$ CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) ", -
                      "/Float=G_Float /Include=MatLab:[Extern.Include] ", -
                      "[--.Src]BBIHdr"
$    CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) /Float=G_Float -
        /Include=MatLab:[Extern.Include] [--.Src]BBIHdr
$    Write Sys$Output "$ CMexG BBIHdr,LibVFBB/Library"
$    CMexG BBIHdr,LibVFBB/Library
$    Write Sys$Output "$ Delete BBIHdr.obj;*"
$    Delete BBIHdr.obj;*
$    Write Sys$Output "$ Purge BBIHdr.mex*"
$    Purge BBIHdr.mex*
$!
$    If ( P1 .eqs. "bbihdr" ) Then $ Goto DONE
$!
$!   bbrhdr('file'[,rhdr_no]); reads a real header
$!
$BBRHDR_V4:
$!
$    If ( arch .eqs. "VAX" )
$    Then
$       Write Sys$Output "$ CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) ", -
                         "/Include=MatLab:[Extern.Include] [--.Src]BBRHdr"
$       CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) -
           /Include=MatLab:[Extern.Include] [--.Src]BBRHdr
$       Write Sys$Output "$ CMexD BBRHdr,LibVFBB/Library"
$       CMexD BBRHdr,LibVFBB/Library
$       Write Sys$Output "$ Delete BBRHdr.obj;*"
$       Delete BBRHdr.obj;*
$       Write Sys$Output "$ Purge BBRHdr.mex*"
$       Purge BBRHdr.mex*
$    EndIf
$    Write Sys$Output "$ CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) ", -
                      "/Float=G_Float /Include=MatLab:[Extern.Include] ", -
                      "[--.Src]BBRHdr"
$    CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) /Float=G_Float -
        /Include=MatLab:[Extern.Include] [--.Src]BBRHdr
$    Write Sys$Output "$ CMexG BBRHdr,LibVFBB/Library"
$    CMexG BBRHdr,LibVFBB/Library
$    Write Sys$Output "$ Delete BBRHdr.obj;*"
$    Delete BBRHdr.obj;*
$    Write Sys$Output "$ Purge BBRHdr.mex*"
$    Purge BBRHdr.mex*
$!
$    If ( P1 .eqs. "bbrhdr" ) Then $ Goto DONE
$!
$!   bbthdr('file'[,thdr_no]); reads an ASCII text header
$!
$BBTHDR_V4:
$!
$    If ( arch .eqs. "VAX" )
$    Then
$       Write Sys$Output "$ CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) ", -
                         "/Include=MatLab:[Extern.Include] [--.Src]BBTHdr"
$       CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) -
           /Include=MatLab:[Extern.Include] [--.Src]BBTHdr
$       Write Sys$Output "$ CMexD BBTHdr,LibVFBB/Library"
$       CMexD BBTHdr,LibVFBB/Library
$       Write Sys$Output "$ Delete BBTHdr.obj;*"
$       Delete BBTHdr.obj;*
$       Write Sys$Output "$ Purge BBTHdr.mex*"
$       Purge BBTHdr.mex*
$    EndIf
$    Write Sys$Output "$ CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) ", -
                      "/Float=G_Float /Include=MatLab:[Extern.Include] ", -
                      "[--.Src]BBTHdr"
$    CC /Define=(MATLAB_MEX_FILE,V4_COMPAT) /Float=G_Float -
        /Include=MatLab:[Extern.Include] [--.Src]BBTHdr
$    Write Sys$Output "$ CMexG BBTHdr,LibVFBB/Library"
$    CMexG BBTHdr,LibVFBB/Library
$    Write Sys$Output "$ Delete BBTHdr.obj;*"
$    Delete BBTHdr.obj;*
$    Write Sys$Output "$ Purge BBTHdr.mex*"
$    Purge BBTHdr.mex*
$!
$    If ( P1 .eqs. "bbthdr" ) Then $ Goto DONE
$!
$ EndIf
$!
$ Goto DONE
$!
$CLEAN:
$!
$ Set NoOn
$ Set Verify
$ Delete BBData.mex*;*,BBData.obj;*
$ Delete BBIHdr.mex*;*,BBIHdr.obj;*
$ Delete BBRHdr.mex*;*,BBRHdr.obj;*
$ Delete BBTHdr.mex*;*,BBTHdr.obj;*
$ junk = 'F$Verify( 0 )'
$ Set On
$!
$DONE:
$!
$ Set Verify
$ Set Default [-]
$ junk = 'F$Verify( 0 )'
$!
$EXIT:
$ Exit 1 + ( 0 * F$Verify( verify ) )
