@ECHO OFF
@REM
@REM LibVFBB.bat - Create library functions for reading headers and time-series
@REM               data from blocked-binary format files for Windows Win32
@REM               (x86).
@REM
@REM Command Prompt command syntax: LibVFBB [ all | libvfbb | clean ]
@REM
@REM
@REM Author:      Lawrence M. Baker
@REM              U.S. Geological Survey
@REM              345 Middlefield Road  MS977
@REM              Menlo Park, CA  94025
@REM              baker@usgs.gov
@REM
@REM                                 Disclaimer
@REM
@REM Although  this  program  has  been  used  by the U.S. Geological Survey, no
@REM warranty, expressed or implied, is made by the USGS as to the accuracy  and
@REM functioning of the program and related program material, nor shall the fact
@REM of distribution constitute  any such warranty,  and  no  responsibility  is
@REM assumed by the USGS in connection therewith.
@REM
@REM
@REM Modification History:
@REM
@REM 14-Feb-2001  L. M. Baker      Original version.
@REM 15-Feb-2001  L. M. Baker      Add from_pc_rhdr.
@REM 28-Feb-2001  L. M. Baker      Add is_little_endian.
@REM  8-Mar-2001  L. M. Baker      Add BBData, BBIHdr, BBRHdr, BBTHdr.
@REM                               Add Fortran-linkage versions.
@REM

@IF /I "%1" == "clean" GOTO :CLEAN

@REM /nologo (suppress display of sign-on banner) /ML (single threaded using
@REM MSVCRTD.LIB) /W3 (warning level) /GX (enable synchronous exception
@REM handling) /O2 (create fast code) /Za (disable extensions, i.e., ANSI C)
@SET CFLAGS=/nologo /ML /W3 /GX /O2 /Za

@ECHO ON
@REM
@REM VFBB File Conversion Routines (C linkage)
@REM
CL /c %CFLAGS% ..\src\bbdata.c
CL /c %CFLAGS% ..\src\bbihdr.c
CL /c %CFLAGS% ..\src\bbrhdr.c
CL /c %CFLAGS% ..\src\bbthdr.c
CL /c %CFLAGS% ..\src\from_vax_ihdr.c
CL /c %CFLAGS% ..\src\from_vax_rhdr.c
CL /c %CFLAGS% ..\src\from_pc_rhdr.c
CL /c %CFLAGS% ..\src\to_vax_ihdr.c
CL /c %CFLAGS% ..\src\to_vax_rhdr.c
@REM
@REM VAX Data Conversion Routines (C linkage)
@REM
CL /c %CFLAGS% ..\src\from_vax_i2.c
CL /c %CFLAGS% ..\src\from_vax_i4.c
CL /c %CFLAGS% ..\src\from_vax_r4.c
CL /c %CFLAGS% ..\src\from_vax_d8.c
CL /c %CFLAGS% ..\src\from_vax_g8.c
CL /c %CFLAGS% ..\src\from_vax_h16.c
CL /c %CFLAGS% ..\src\to_vax_i2.c
CL /c %CFLAGS% ..\src\to_vax_i4.c
CL /c %CFLAGS% ..\src\to_vax_r4.c
CL /c %CFLAGS% ..\src\to_vax_d8.c
CL /c %CFLAGS% ..\src\to_vax_g8.c
CL /c %CFLAGS% ..\src\to_vax_h16.c
CL /c %CFLAGS% ..\src\is_little_endian.c
@REM
@REM Create a static library
@REM
LIB /nologo /out:libvfbb.lib ^
    bbdata.obj        bbihdr.obj        bbrhdr.obj        bbthdr.obj        ^
    from_vax_ihdr.obj from_vax_rhdr.obj from_pc_rhdr.obj  to_vax_ihdr.obj   ^
    to_vax_rhdr.obj   from_vax_i2.obj   from_vax_i4.obj   from_vax_r4.obj   ^
    from_vax_d8.obj   from_vax_g8.obj   from_vax_h16.obj  to_vax_i2.obj     ^
    to_vax_i4.obj     to_vax_r4.obj     to_vax_d8.obj     to_vax_g8.obj     ^
    to_vax_h16.obj    is_little_endian.obj
DEL bbdata.obj        bbihdr.obj        bbrhdr.obj        bbthdr.obj        ^
    from_vax_ihdr.obj from_vax_rhdr.obj from_pc_rhdr.obj  to_vax_ihdr.obj   ^
    to_vax_rhdr.obj   from_vax_i2.obj   from_vax_i4.obj   from_vax_r4.obj   ^
    from_vax_d8.obj   from_vax_g8.obj   from_vax_h16.obj  to_vax_i2.obj     ^
    to_vax_i4.obj     to_vax_r4.obj     to_vax_d8.obj     to_vax_g8.obj     ^
    to_vax_h16.obj    is_little_endian.obj
@ECHO OFF

@SET CFLAGS=%CFLAGS% -DUPCASE -DFORTRAN_LINKAGE=__stdcall

@ECHO ON
@REM
@REM VFBB File Conversion Routines (Fortran linkage)
@REM
CL /c %CFLAGS% /FoBBDATA@n.obj           ..\src\bbdata.c
CL /c %CFLAGS% /FoBBIHDR@n.obj           ..\src\bbihdr.c
CL /c %CFLAGS% /FoBBRHDR@n.obj           ..\src\bbrhdr.c
CL /c %CFLAGS% /FoBBTHDR@n.obj           ..\src\bbthdr.c
CL /c %CFLAGS% /FoFROM_VAX_IHDR@n.obj    ..\src\from_vax_ihdr.c
CL /c %CFLAGS% /FoFROM_VAX_RHDR@n.obj    ..\src\from_vax_rhdr.c
CL /c %CFLAGS% /FoFROM_PC_RHDR@n.obj     ..\src\from_pc_rhdr.c
CL /c %CFLAGS% /FoTO_VAX_IHDR@n.obj      ..\src\to_vax_ihdr.c
CL /c %CFLAGS% /FoTO_VAX_RHDR@n.obj      ..\src\to_vax_rhdr.c
@REM
@REM VAX Data Conversion Routines (Fortran linkage)
@REM
CL /c %CFLAGS% /FoFROM_VAX_I2@n.obj      ..\src\from_vax_i2.c
CL /c %CFLAGS% /FoFROM_VAX_I4@n.obj      ..\src\from_vax_i4.c
CL /c %CFLAGS% /FoFROM_VAX_R4@n.obj      ..\src\from_vax_r4.c
CL /c %CFLAGS% /FoFROM_VAX_D8@n.obj      ..\src\from_vax_d8.c
CL /c %CFLAGS% /FoFROM_VAX_G8@n.obj      ..\src\from_vax_g8.c
CL /c %CFLAGS% /FoFROM_VAX_H16@n.obj     ..\src\from_vax_h16.c
CL /c %CFLAGS% /FoTO_VAX_I2@n.obj        ..\src\to_vax_i2.c
CL /c %CFLAGS% /FoTO_VAX_I4@n.obj        ..\src\to_vax_i4.c
CL /c %CFLAGS% /FoTO_VAX_R4@n.obj        ..\src\to_vax_r4.c
CL /c %CFLAGS% /FoTO_VAX_D8@n.obj        ..\src\to_vax_d8.c
CL /c %CFLAGS% /FoTO_VAX_G8@n.obj        ..\src\to_vax_g8.c
CL /c %CFLAGS% /FoTO_VAX_H16@n.obj       ..\src\to_vax_h16.c
CL /c %CFLAGS% /FoIS_LITTLE_ENDIAN@n.obj ..\src\is_little_endian.c
LIB /nologo libvfbb.lib ^
    BBDATA@n.obj        BBIHDR@n.obj        BBRHDR@n.obj        ^
    BBTHDR@n.obj        FROM_VAX_IHDR@n.obj FROM_VAX_RHDR@n.obj ^
    FROM_PC_RHDR@n.obj  TO_VAX_IHDR@n.obj   TO_VAX_RHDR@n.obj   ^
    FROM_VAX_I2@n.obj   FROM_VAX_I4@n.obj   FROM_VAX_R4@n.obj   ^
    FROM_VAX_D8@n.obj   FROM_VAX_G8@n.obj   FROM_VAX_H16@n.obj  ^
    TO_VAX_I2@n.obj     TO_VAX_I4@n.obj     TO_VAX_R4@n.obj     ^
    TO_VAX_D8@n.obj     TO_VAX_G8@n.obj     TO_VAX_H16@n.obj    ^
    IS_LITTLE_ENDIAN@n.obj
DEL BBDATA@n.obj        BBIHDR@n.obj        BBRHDR@n.obj        ^
    BBTHDR@n.obj        FROM_VAX_IHDR@n.obj FROM_VAX_RHDR@n.obj ^
    FROM_PC_RHDR@n.obj  TO_VAX_IHDR@n.obj   TO_VAX_RHDR@n.obj   ^
    FROM_VAX_I2@n.obj   FROM_VAX_I4@n.obj   FROM_VAX_R4@n.obj   ^
    FROM_VAX_D8@n.obj   FROM_VAX_G8@n.obj   FROM_VAX_H16@n.obj  ^
    TO_VAX_I2@n.obj     TO_VAX_I4@n.obj     TO_VAX_R4@n.obj     ^
    TO_VAX_D8@n.obj     TO_VAX_G8@n.obj     TO_VAX_H16@n.obj    ^
    IS_LITTLE_ENDIAN@n.obj
@GOTO :EOF

:CLEAN
@ECHO ON
DEL libvfbb.lib
DEL bbdata.obj        bbihdr.obj        bbrhdr.obj        bbthdr.obj        ^
    from_vax_ihdr.obj from_vax_rhdr.obj from_pc_rhdr.obj  to_vax_ihdr.obj   ^
    to_vax_rhdr.obj   from_vax_i2.obj   from_vax_i4.obj   from_vax_r4.obj   ^
    from_vax_d8.obj   from_vax_g8.obj   from_vax_h16.obj  to_vax_i2.obj     ^
    to_vax_i4.obj     to_vax_r4.obj     to_vax_d8.obj     to_vax_g8.obj     ^
    to_vax_h16.obj    is_little_endian.obj
DEL BBDATA@n.obj        BBIHDR@n.obj        BBRHDR@n.obj        ^
    BBTHDR@n.obj        FROM_VAX_IHDR@n.obj FROM_VAX_RHDR@n.obj ^
    FROM_PC_RHDR@n.obj  TO_VAX_IHDR@n.obj   TO_VAX_RHDR@n.obj   ^
    FROM_VAX_I2@n.obj   FROM_VAX_I4@n.obj   FROM_VAX_R4@n.obj   ^
    FROM_VAX_D8@n.obj   FROM_VAX_G8@n.obj   FROM_VAX_H16@n.obj  ^
    TO_VAX_I2@n.obj     TO_VAX_I4@n.obj     TO_VAX_R4@n.obj     ^
    TO_VAX_D8@n.obj     TO_VAX_G8@n.obj     TO_VAX_H16@n.obj    ^
    IS_LITTLE_ENDIAN@n.obj
